comments.MyComments (My Comments) — amici1

# `comments.MyComments` (My Comments)

Columns

- `<django.db.models.fields.BigAutoField: id>`

- `<django.db.models.fields.DateTimeField: modified>`

- `<django.db.models.fields.DateTimeField: created>`

- `<django.db.models.fields.related.ForeignKey: user>`

- `<django.db.models.fields.related.ForeignKey: owner_type>`

- `<lino.modlib.gfks.fields.GenericForeignKeyIdField: owner_id>`

- `<lino.core.fields.RichTextField: body>`

- `<lino.core.fields.RichTextField: body_short_preview>`

- `<lino.core.fields.RichTextField: body_full_preview>`

- `<django.db.models.fields.related.ForeignKey: reply_to>`

- `<django.db.models.fields.BooleanField: private>`

- `<django.db.models.fields.related.ForeignKey: comment_type>`

- `<lino.modlib.gfks.fields.GenericForeignKey object at 0x7fc81d101048>`

Detail fields

- `<Panel general_1 in lino.modlib.comments.ui.CommentDetail on lino.modlib.comments.ui.Comments>`

- `<Panel more_1 in lino.modlib.comments.ui.CommentDetail on lino.modlib.comments.ui.Comments>`

Actions

- HTML (show_as_html) : Show this table in Bootstrap3 interface

- Table (landscape) (as_pdf) : Show this table as a pdf document.

- Table (portrait) (as_pdf_p) : Show this table as a pdf document.

- Export to .xls (export_excel) : Export this table as an .xls document

- None (grid_post) : See `<lino.core.actions.CreateRow grid_post>`.

- None (grid_put) : See `<lino.core.actions.SaveGridCell grid_put>`.

- New (insert) : Open a dialog window to insert a new Comment.

- Create (submit_insert) : Create the record and open a detail window on it

- Detail (detail) : Open a detail window on this record.

- Delete (delete_selected) : Delete this record

- Check data (check_data) : See `<lino.modlib.checkdata.models.UpdateProblemsByController check_data ('Check data')>`.

- Emotion (do_pick_my_emotion) : See `<lino.core.model.QuickSetChoice do_pick_my_emotion ('Emotion')>`.

- Fix data problems (fix_problems) : See `<lino.modlib.checkdata.models.FixProblemsByController fix_problems ('Fix data problems')>`.

- None (grid) : See `<lino.core.actions.ShowTable grid>`.

- None (open_help) : See `<lino.core.actions.OpenHelpWindow open_help>`.

- Preview (preview_publication) : See `<lino.modlib.publisher.mixins.PreviewPublication preview_publication ('Preview')>`.

- None (validate) : See `<lino.core.actions.ValidateForm validate>`.

- Save (submit_detail) : Save changes in this form

Filter parameters

- `<lino.core.choicelists.ChoiceListField: observed_event>`

- `<django.db.models.fields.DateField: start_date>`

- `<django.db.models.fields.DateField: end_date>`

- `<django.db.models.fields.related.ForeignKey: user>`

- `<django.db.models.fields.related.ForeignKey: reply_to>`

## Filter parameters